==> libstpk-0.9.3.0.tar.gz: libstpk-0.9.3.0/demo/NM01/val_define.f90 <==
module val_define
! ѿ
! ѿ̾̿̾§
! ¿ -> r,  -> i, ʣǿ -> c
! ʿѾ -> b,  -> p
! ȯŸ -> old, new
!-- 󤪤Ӱѿ save °Ĥ module ɤ߹Ȥͤ
!  ¸ͤˤ.

  implicit none

!-- value definition
!-- integer, save part
  integer, save :: nr  ! r Ŀ
  integer, save :: ntheta  ! theta Ŀ
  integer, save :: nt  ! ֥ƥå
  integer, save :: jnt  ! Ѵˡˤʬ
  integer, save :: hnt  ! theta ȿ
  integer, save :: ni  ! r Ŀ(ͥǡ)
  integer, save :: dmpstp  ! ״ֳ
  integer, save :: init_n  ! ȿ

!-- logical part
  logical, save :: nl_flag  ! ׻ԤɤΥե饰

!-- real, save part
  real, save :: rmin  ! ư
  real, save :: dr  ! ưʻҴֳ
  real, save :: dt  ! ưʻҴֳ
  real, save :: r_dmp  ! 쥤꡼ԥ󥰤򤫤Ⱦ
  real, save :: diff_r  ! ưγȻ
  real, save :: diff_t  ! γȻ
!-- 1d val
  real, save, allocatable, dimension(:) :: ri  ! 顼ưºɸ
  real, save, allocatable, dimension(:) :: rs  ! 顼ưºɸ
  real, save, allocatable, dimension(:) :: rv  ! ٥ȥưºɸ
  real, save, allocatable, dimension(:) :: theta  ! ɸ
  real, save, allocatable, dimension(:) :: hb  ! ݥƥ󥷥ʿѾ
  real, save, allocatable, dimension(:) :: ub  ! ưʿѾ
  real, save, allocatable, dimension(:) :: vb  ! ʿѾ
  real, save, allocatable, dimension(:) :: hib  ! ݥƥ󥷥ʿѾ
  real, save, allocatable, dimension(:) :: uib  ! ưʿѾ
  real, save, allocatable, dimension(:) :: vib  ! ʿѾ
  real, save, allocatable, dimension(:) :: dhbdr  ! ݥƥ󥷥ʿѾ
  real, save, allocatable, dimension(:) :: dubdr  ! ưʿѾ
  real, save, allocatable, dimension(:) :: dvbdr  ! ʿѾ
  real, save, allocatable, dimension(:) :: ubdub
  real, save, allocatable, dimension(:) :: ubdvb
  real, save, allocatable, dimension(:) :: ubdhb
  real, save, allocatable, dimension(:) :: vbdub
  real, save, allocatable, dimension(:) :: vbdvb
  real, save, allocatable, dimension(:) :: vbdhb
  real, save, allocatable, dimension(:) :: hbdub
  real, save, allocatable, dimension(:) :: hbdvb
  real, save, allocatable, dimension(:) :: hbdhb
  real, save, allocatable, dimension(:) :: epsu  ! 쥤꡼ԥ󥰷 u
  real, save, allocatable, dimension(:) :: epsv  ! 쥤꡼ԥ󥰷 v
  real, save, allocatable, dimension(:) :: epsh  ! 쥤꡼ԥ󥰷 h
!-- 2d val
  real, save, allocatable, dimension(:,:) :: urp_dmp  ! ư® dmp
  real, save, allocatable, dimension(:,:) :: vrp_dmp  ! ® dmp
  real, save, allocatable, dimension(:,:) :: hrp_dmp  ! ݥƥ󥷥 dmp
  real, save, allocatable, dimension(:,:) :: urp_old  ! ư® old
  real, save, allocatable, dimension(:,:) :: vrp_old  ! ® old
  real, save, allocatable, dimension(:,:) :: hrp_old  ! ݥƥ󥷥 old
  real, save, allocatable, dimension(:,:) :: uip_old  ! ư® old
  real, save, allocatable, dimension(:,:) :: vip_old  ! ® old
  real, save, allocatable, dimension(:,:) :: hip_old  ! ݥƥ󥷥 old
  real, save, allocatable, dimension(:,:) :: urp_new  ! ư® new
  real, save, allocatable, dimension(:,:) :: vrp_new  ! ® new
  real, save, allocatable, dimension(:,:) :: hrp_new  ! ݥƥ󥷥 new
  real, save, allocatable, dimension(:,:) :: uip_new  ! ư® new
  real, save, allocatable, dimension(:,:) :: vip_new  ! ® new
  real, save, allocatable, dimension(:,:) :: hip_new  ! ݥƥ󥷥 new
  real, save, allocatable, dimension(:,:) :: durpdr
  real, save, allocatable, dimension(:,:) :: dvrpdr
  real, save, allocatable, dimension(:,:) :: dhrpdr
  real, save, allocatable, dimension(:,:) :: duipdr
  real, save, allocatable, dimension(:,:) :: dvipdr
  real, save, allocatable, dimension(:,:) :: dhipdr
  real, save, allocatable, dimension(:,:) :: coril  ! ꥪѥ᡼

!-- complex, save part

  complex, parameter :: img=( 0.0, 1.0 )  ! ñ

  complex, save, allocatable, dimension(:,:) :: ucp_dmp  ! ư® old
  complex, save, allocatable, dimension(:,:) :: vcp_dmp  ! ® old
  complex, save, allocatable, dimension(:,:) :: hcp_dmp  ! ݥƥ󥷥 old
  complex, save, allocatable, dimension(:,:) :: ucp_tmp  ! ư® old
  complex, save, allocatable, dimension(:,:) :: vcp_tmp  ! ® old
  complex, save, allocatable, dimension(:,:) :: hcp_tmp  ! ݥƥ󥷥 old
  complex, save, allocatable, dimension(:,:) :: ucp_old  ! ư® old
  complex, save, allocatable, dimension(:,:) :: vcp_old  ! ® old
  complex, save, allocatable, dimension(:,:) :: hcp_old  ! ݥƥ󥷥 old
  complex, save, allocatable, dimension(:,:) :: ucp_new  ! ư® new
  complex, save, allocatable, dimension(:,:) :: vcp_new  ! ® new
  complex, save, allocatable, dimension(:,:) :: hcp_new  ! ݥƥ󥷥 new
  complex, save, allocatable, dimension(:,:) :: ducpdr
  complex, save, allocatable, dimension(:,:) :: dvcpdr
  complex, save, allocatable, dimension(:,:) :: dhcpdr
  complex, save, allocatable, dimension(:,:) :: updup  ! updup
  complex, save, allocatable, dimension(:,:) :: updvp  ! updvp
  complex, save, allocatable, dimension(:,:) :: updhp  ! updhp
  complex, save, allocatable, dimension(:,:) :: vpdup  ! vpdup
  complex, save, allocatable, dimension(:,:) :: vpdvp  ! vpdvp
  complex, save, allocatable, dimension(:,:) :: vpdhp  ! vpdhp
  complex, save, allocatable, dimension(:,:) :: hpdup  ! hpdup
  complex, save, allocatable, dimension(:,:) :: hpdvp  ! hpdvp
  complex, save, allocatable, dimension(:,:) :: hpdhp  ! hpdhp
  complex, save, allocatable, dimension(:,:) :: ubdup  ! ubdup
  complex, save, allocatable, dimension(:,:) :: ubdvp  ! ubdvp
  complex, save, allocatable, dimension(:,:) :: ubdhp  ! ubdhp
  complex, save, allocatable, dimension(:,:) :: vbdup  ! vbdup
  complex, save, allocatable, dimension(:,:) :: vbdvp  ! vbdvp
  complex, save, allocatable, dimension(:,:) :: vbdhp  ! vbdhp
  complex, save, allocatable, dimension(:,:) :: hbdup  ! hbdup
  complex, save, allocatable, dimension(:,:) :: hbdvp  ! hbdvp
  complex, save, allocatable, dimension(:,:) :: hbdhp  ! hbdhp
  complex, save, allocatable, dimension(:,:) :: updub  ! updub
  complex, save, allocatable, dimension(:,:) :: updvb  ! updvb
  complex, save, allocatable, dimension(:,:) :: updhb  ! updhb
  complex, save, allocatable, dimension(:,:) :: vpdub  ! vpdub
  complex, save, allocatable, dimension(:,:) :: vpdvb  ! vpdvb
  complex, save, allocatable, dimension(:,:) :: vpdhb  ! vpdhb
  complex, save, allocatable, dimension(:,:) :: hpdub  ! hpdub
  complex, save, allocatable, dimension(:,:) :: hpdvb  ! hpdvb
  complex, save, allocatable, dimension(:,:) :: hpdhb  ! hpdhb
  complex, save, allocatable, dimension(:,:) :: ubup  ! ubup
  complex, save, allocatable, dimension(:,:) :: ubvp  ! ubvp
  complex, save, allocatable, dimension(:,:) :: ubhp  ! ubhp
  complex, save, allocatable, dimension(:,:) :: upup  ! upup
  complex, save, allocatable, dimension(:,:) :: upvp  ! upvp
  complex, save, allocatable, dimension(:,:) :: uphp  ! uphp
  complex, save, allocatable, dimension(:,:) :: vbup  ! vbup
  complex, save, allocatable, dimension(:,:) :: vbvp  ! vbvp
  complex, save, allocatable, dimension(:,:) :: vbhp  ! vbhp
  complex, save, allocatable, dimension(:,:) :: vpup  ! vpup
  complex, save, allocatable, dimension(:,:) :: vpvp  ! vpvp
  complex, save, allocatable, dimension(:,:) :: vphp  ! vphp
  complex, save, allocatable, dimension(:,:) :: hbup  ! hbup
  complex, save, allocatable, dimension(:,:) :: hbvp  ! hbvp
  complex, save, allocatable, dimension(:,:) :: hbhp  ! hbhp
  complex, save, allocatable, dimension(:,:) :: hpup  ! hpup
  complex, save, allocatable, dimension(:,:) :: hpvp  ! hpvp
  complex, save, allocatable, dimension(:,:) :: hphp  ! hphp
  complex, save, allocatable, dimension(:,:) :: forceu  ! forceu
  complex, save, allocatable, dimension(:,:) :: forcev  ! forcev
  complex, save, allocatable, dimension(:,:) :: forceh  ! forceh
  complex, save, allocatable, dimension(:,:) :: forceua  ! forceu
  complex, save, allocatable, dimension(:,:) :: forceva  ! forcev
  complex, save, allocatable, dimension(:,:) :: forceha  ! forceh
  complex, save, allocatable, dimension(:,:) :: eup  ! 쥤꡼ԥ󥰹 u
  complex, save, allocatable, dimension(:,:) :: evp  ! 쥤꡼ԥ󥰹 v
  complex, save, allocatable, dimension(:,:) :: ehp  ! 쥤꡼ԥ󥰹 h
  complex, save, allocatable, dimension(:,:) :: corilu  ! ꥪ u
  complex, save, allocatable, dimension(:,:) :: corilv  ! ꥪ v
  complex, save, allocatable, dimension(:,:) :: fup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdupdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdvpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdhpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdupdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdvpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdhpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdupdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdvpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdhpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdupdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdvpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdhpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fuphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhpdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhpdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiuphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fihphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fihpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fihpdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fihpdhp  ! ɾ



!-- character part
  character(80) :: finame  ! ͥե̾
  character(80) :: foname  ! ͥե̾
  character(1) :: time_flag  ! ֥˴ؤե饰
  character(10) :: force_flag  ! γƸ̤뤿Υե饰

!-- namelist ɤ߹

end module

==> libstpk-0.9.5.0.tar.gz: libstpk-0.9.5.0/demo/NM01/val_define.f90 <==
module val_define
! ѿ
! ѿ̾̿̾§
! ¿ -> r,  -> i, ʣǿ -> c
! ʿѾ -> b,  -> p
! ȯŸ -> old, new
!-- 󤪤Ӱѿ save °Ĥ module ɤ߹Ȥͤ
!  ¸ͤˤ.

  implicit none

!-- value definition
!-- integer, save part
  integer, save :: nr  ! r Ŀ
  integer, save :: ntheta  ! theta Ŀ
  integer, save :: nt  ! ֥ƥå
  integer, save :: jnt  ! Ѵˡˤʬ
  integer, save :: hnt  ! theta ȿ
  integer, save :: ni  ! r Ŀ(ͥǡ)
  integer, save :: dmpstp  ! ״ֳ
  integer, save :: init_n  ! ȿ
  integer, save, dimension(:) :: pfact(5)  ! ǰʬ
  integer, save, dimension(:) :: p1fact(5)  ! ǰʬ

!-- logical part
  logical, save :: nl_flag  ! ׻ԤɤΥե饰

!-- real, save part
  real, save :: rmin  ! ư
  real, save :: dr  ! ưʻҴֳ
  real, save :: dt  ! ưʻҴֳ
  real, save :: r_dmp  ! 쥤꡼ԥ󥰤򤫤Ⱦ
  real, save :: diff_r  ! ưγȻ
  real, save :: diff_t  ! γȻ
!-- 1d val
  real, save, allocatable, dimension(:) :: ri  ! 顼ưºɸ
  real, save, allocatable, dimension(:) :: rs  ! 顼ưºɸ
  real, save, allocatable, dimension(:) :: rv  ! ٥ȥưºɸ
  real, save, allocatable, dimension(:) :: theta  ! ɸ
  real, save, allocatable, dimension(:) :: hb  ! ݥƥ󥷥ʿѾ
  real, save, allocatable, dimension(:) :: ub  ! ưʿѾ
  real, save, allocatable, dimension(:) :: vb  ! ʿѾ
  real, save, allocatable, dimension(:) :: hib  ! ݥƥ󥷥ʿѾ
  real, save, allocatable, dimension(:) :: uib  ! ưʿѾ
  real, save, allocatable, dimension(:) :: vib  ! ʿѾ
  real, save, allocatable, dimension(:) :: dhbdr  ! ݥƥ󥷥ʿѾ
  real, save, allocatable, dimension(:) :: dubdr  ! ưʿѾ
  real, save, allocatable, dimension(:) :: dvbdr  ! ʿѾ
  real, save, allocatable, dimension(:) :: ubdub
  real, save, allocatable, dimension(:) :: ubdvb
  real, save, allocatable, dimension(:) :: ubdhb
  real, save, allocatable, dimension(:) :: vbdub
  real, save, allocatable, dimension(:) :: vbdvb
  real, save, allocatable, dimension(:) :: vbdhb
  real, save, allocatable, dimension(:) :: hbdub
  real, save, allocatable, dimension(:) :: hbdvb
  real, save, allocatable, dimension(:) :: hbdhb
  real, save, allocatable, dimension(:) :: epsu  ! 쥤꡼ԥ󥰷 u
  real, save, allocatable, dimension(:) :: epsv  ! 쥤꡼ԥ󥰷 v
  real, save, allocatable, dimension(:) :: epsh  ! 쥤꡼ԥ󥰷 h
!-- 2d val
  real, save, allocatable, dimension(:,:) :: urp_dmp  ! ư® dmp
  real, save, allocatable, dimension(:,:) :: vrp_dmp  ! ® dmp
  real, save, allocatable, dimension(:,:) :: hrp_dmp  ! ݥƥ󥷥 dmp
  real, save, allocatable, dimension(:,:) :: urp_old  ! ư® old
  real, save, allocatable, dimension(:,:) :: vrp_old  ! ® old
  real, save, allocatable, dimension(:,:) :: hrp_old  ! ݥƥ󥷥 old
  real, save, allocatable, dimension(:,:) :: uip_old  ! ư® old
  real, save, allocatable, dimension(:,:) :: vip_old  ! ® old
  real, save, allocatable, dimension(:,:) :: hip_old  ! ݥƥ󥷥 old
  real, save, allocatable, dimension(:,:) :: urp_new  ! ư® new
  real, save, allocatable, dimension(:,:) :: vrp_new  ! ® new
  real, save, allocatable, dimension(:,:) :: hrp_new  ! ݥƥ󥷥 new
  real, save, allocatable, dimension(:,:) :: uip_new  ! ư® new
  real, save, allocatable, dimension(:,:) :: vip_new  ! ® new
  real, save, allocatable, dimension(:,:) :: hip_new  ! ݥƥ󥷥 new
  real, save, allocatable, dimension(:,:) :: durpdr
  real, save, allocatable, dimension(:,:) :: dvrpdr
  real, save, allocatable, dimension(:,:) :: dhrpdr
  real, save, allocatable, dimension(:,:) :: duipdr
  real, save, allocatable, dimension(:,:) :: dvipdr
  real, save, allocatable, dimension(:,:) :: dhipdr
  real, save, allocatable, dimension(:,:) :: coril  ! ꥪѥ᡼

!-- complex, save part

  complex, save, allocatable, dimension(:,:) :: omega_br  ! ;ǰž
  complex, save, allocatable, dimension(:,:) :: omega_nr  ! ž
  complex, save, allocatable, dimension(:,:) :: omega_bi  ! ;ǰž
  complex, save, allocatable, dimension(:,:) :: omega_ni  ! ž
  complex, save, allocatable, dimension(:,:) :: omega_br1 ! ;ǰž
  complex, save, allocatable, dimension(:,:) :: omega_nr1 ! ž
  complex, save, allocatable, dimension(:,:) :: omega_bi1 ! ;ǰž
  complex, save, allocatable, dimension(:,:) :: omega_ni1 ! ž
  complex, save, allocatable, dimension(:,:) :: ucp_dmp   ! ư® old
  complex, save, allocatable, dimension(:,:) :: vcp_dmp   ! ® old
  complex, save, allocatable, dimension(:,:) :: hcp_dmp   ! ݥƥ󥷥 old
  complex, save, allocatable, dimension(:,:) :: ucp_tmp   ! ư® old
  complex, save, allocatable, dimension(:,:) :: vcp_tmp   ! ® old
  complex, save, allocatable, dimension(:,:) :: hcp_tmp   ! ݥƥ󥷥 old
  complex, save, allocatable, dimension(:,:) :: ucp_old   ! ư® old
  complex, save, allocatable, dimension(:,:) :: vcp_old   ! ® old
  complex, save, allocatable, dimension(:,:) :: hcp_old   ! ݥƥ󥷥 old
  complex, save, allocatable, dimension(:,:) :: ucp_new   ! ư® new
  complex, save, allocatable, dimension(:,:) :: vcp_new   ! ® new
  complex, save, allocatable, dimension(:,:) :: hcp_new   ! ݥƥ󥷥 new
  complex, save, allocatable, dimension(:,:) :: ducpdr
  complex, save, allocatable, dimension(:,:) :: dvcpdr
  complex, save, allocatable, dimension(:,:) :: dhcpdr
  complex, save, allocatable, dimension(:,:) :: updup  ! updup
  complex, save, allocatable, dimension(:,:) :: updvp  ! updvp
  complex, save, allocatable, dimension(:,:) :: updhp  ! updhp
  complex, save, allocatable, dimension(:,:) :: vpdup  ! vpdup
  complex, save, allocatable, dimension(:,:) :: vpdvp  ! vpdvp
  complex, save, allocatable, dimension(:,:) :: vpdhp  ! vpdhp
  complex, save, allocatable, dimension(:,:) :: hpdup  ! hpdup
  complex, save, allocatable, dimension(:,:) :: hpdvp  ! hpdvp
  complex, save, allocatable, dimension(:,:) :: hpdhp  ! hpdhp
  complex, save, allocatable, dimension(:,:) :: ubdup  ! ubdup
  complex, save, allocatable, dimension(:,:) :: ubdvp  ! ubdvp
  complex, save, allocatable, dimension(:,:) :: ubdhp  ! ubdhp
  complex, save, allocatable, dimension(:,:) :: vbdup  ! vbdup
  complex, save, allocatable, dimension(:,:) :: vbdvp  ! vbdvp
  complex, save, allocatable, dimension(:,:) :: vbdhp  ! vbdhp
  complex, save, allocatable, dimension(:,:) :: hbdup  ! hbdup
  complex, save, allocatable, dimension(:,:) :: hbdvp  ! hbdvp
  complex, save, allocatable, dimension(:,:) :: hbdhp  ! hbdhp
  complex, save, allocatable, dimension(:,:) :: updub  ! updub
  complex, save, allocatable, dimension(:,:) :: updvb  ! updvb
  complex, save, allocatable, dimension(:,:) :: updhb  ! updhb
  complex, save, allocatable, dimension(:,:) :: vpdub  ! vpdub
  complex, save, allocatable, dimension(:,:) :: vpdvb  ! vpdvb
  complex, save, allocatable, dimension(:,:) :: vpdhb  ! vpdhb
  complex, save, allocatable, dimension(:,:) :: hpdub  ! hpdub
  complex, save, allocatable, dimension(:,:) :: hpdvb  ! hpdvb
  complex, save, allocatable, dimension(:,:) :: hpdhb  ! hpdhb
  complex, save, allocatable, dimension(:,:) :: ubup  ! ubup
  complex, save, allocatable, dimension(:,:) :: ubvp  ! ubvp
  complex, save, allocatable, dimension(:,:) :: ubhp  ! ubhp
  complex, save, allocatable, dimension(:,:) :: upvp  ! upvp
  complex, save, allocatable, dimension(:,:) :: uphp  ! uphp
  complex, save, allocatable, dimension(:,:) :: vbup  ! vbup
  complex, save, allocatable, dimension(:,:) :: vbvp  ! vbvp
  complex, save, allocatable, dimension(:,:) :: vbhp  ! vbhp
  complex, save, allocatable, dimension(:,:) :: vpup  ! vpup
  complex, save, allocatable, dimension(:,:) :: vpvp  ! vpvp
  complex, save, allocatable, dimension(:,:) :: hbup  ! hbup
  complex, save, allocatable, dimension(:,:) :: hbvp  ! hbvp
  complex, save, allocatable, dimension(:,:) :: hbhp  ! hbhp
  complex, save, allocatable, dimension(:,:) :: hpup  ! hpup
  complex, save, allocatable, dimension(:,:) :: hpvp  ! hpvp
  complex, save, allocatable, dimension(:,:) :: forceu  ! forceu
  complex, save, allocatable, dimension(:,:) :: forcev  ! forcev
  complex, save, allocatable, dimension(:,:) :: forceh  ! forceh
  complex, save, allocatable, dimension(:,:) :: forceua  ! forceu
  complex, save, allocatable, dimension(:,:) :: forceva  ! forcev
  complex, save, allocatable, dimension(:,:) :: forceha  ! forceh
  complex, save, allocatable, dimension(:,:) :: eup  ! 쥤꡼ԥ󥰹 u
  complex, save, allocatable, dimension(:,:) :: evp  ! 쥤꡼ԥ󥰹 v
  complex, save, allocatable, dimension(:,:) :: ehp  ! 쥤꡼ԥ󥰹 h
  complex, save, allocatable, dimension(:,:) :: corilu  ! ꥪ u
  complex, save, allocatable, dimension(:,:) :: corilv  ! ꥪ v
  complex, save, allocatable, dimension(:,:) :: fup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdupdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdvpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdhpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdupdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdvpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fdhpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdupdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdvpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdhpdr  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdupdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdvpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: frdhpdt  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fuphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fupdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fvpdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhpdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fhpdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiuphp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fiupdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpdvp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fivpdhp  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fihpdup  ! ɾ
  complex, save, allocatable, dimension(:,:) :: fihpdvp  ! ɾ



!-- character part
  character(80) :: finame  ! ͥե̾
  character(80) :: foname  ! ͥե̾
  character(1) :: time_flag  ! ֥˴ؤե饰
  character(10) :: force_flag  ! γƸ̤뤿Υե饰

!-- namelist ɤ߹

end module
